from .. import Provider as BaseProvider


class Provider(BaseProvider):
    jobs = [
        "Agent posredovanja u prometu nekretnina",
        "Alatničar",
        "Arhivist",
        "Arhivski savjetnik",
        "Arhivski tehničar",
        "Autoelektričar",
        "Autolakirer",
        "Autolimar",
        "Automehaničar",
        "Autoserviser",
        "Bravar",
        "Brodostrojarski inspektor",
        "Brodski mehaničar",
        "Dentalni asistent",
        "Dentalni tehničar",
        "Dimnjačar",
        "Diplomirana medicinska sestra/medicinski tehničar",
        "Diplomirani fizioterapeut",
        "Diplomirani knjižničar",
        "Diplomirani sanitarni inženjer",
        "Direktor predstavništva",
        "Direktor turističkog ureda turističke zajednice",
        "Dispečer leta / operativni kontrolor prometa",
        "Djelatnik koji obavlja poslove izvođenja glasnog pucnja",
        "Djelatnik koji obavlja poslove izvođenja javnog vatrometa",
        "Djelatnik koji obavlja poslove miniranja",
        "Djelatnik koji obavlja poslove miniranja pri razminiranju",
        "Djelatnik koji obavlja poslove podzemnih miniranja",
        "Djelatnik koji obavlja poslove pripreme miniranja",
        "Djelatnik koji obavlja poslove specijalnih miniranja",
        "Djelatnik službe za zaštitu od požara",
        "Djelatnik za obavljanje poslova zaštite od požara i unapređenje stanja zaštite od požara",
        "Doktor dentalne medicine",
        "Doktor dentalne medicine specijalist",
        "Doktor medicine",
        "Doktor medicine specijalist",
        "Dokumentarist",
        "Dokumentarist savjetnik",
        "Dočasnik",
        "Edukacijski rehabilitator",
        "Elektroinstalater",
        "Elektromehaničar",
        "Elektroničar – mehaničar",
        "Farmaceutski tehničar",
        "Fasader",
        "Fizioterapeutski tehničar",
        "Fotograf",
        "Frizer",
        "Galanterist",
        "Geološki tehničar",
        "Glavni inspektor zaštite okoliša",
        "Glavni nadzornik",
        "Glazbalar",
        "Graditelj brodova",
        "Graditelj orgulja",
        "Hidrograđevinski  inspektor",
        "Informatičar",
        "Informatičar savjetnik",
        "Inspektor sigurnosti unutarnje plovidbe",
        "Inspektor zaštite okoliša",
        "Inspektor zaštite prirode",
        "Instalater grijanja i klimatizacije",
        "Instruktor vožnje",
        "Inženjer geologije",
        "Inženjer gradilišta",
        "Inženjer medicinske radiologije",
        "Inženjer medicinsko- laboratorijske dijagnostike",
        "Inženjer naftnog rudarstva",
        "Inženjer rudarstva",
        "Kemijski čistač",
        "Klesar",
        "Klobučar",
        "Knjižničar",
        "Knjižničarski savjetnik",
        "Kondukter",
        "Kontrolor zračnog prometa",
        "Konzervator",
        "Konzervator savjetnik",
        "Konzervator tehničar",
        "Konzervator – restaurator savjetnik",
        "Konzervator –  restaurator",
        "Koordinator zaštite na radu",
        "Kormilar",
        "Kotlar",
        "Kovač",
        "Kozmetičar",
        "Kriminalist",
        "Krojač muške odjeće",
        "Krojač ženske odjeće",
        "Krovopokrivač",
        "Krznar",
        "Kuhar",
        "Kustos",
        "Lektor hrvatskog jezika na stranim visokoškolskim ustanovama",
        "Limar",
        "Ljekarnik",
        "Ljekarnik specijalist",
        "Ljevač",
        "Lovac",
        "Lovočuvar",
        "Magistar sanitarnog inženjerstva",
        "Magistar sestrinstva",
        "Maser – kupeljar",
        "Medicinska sestra opće njege",
        "Medicinska sestra-medicinski tehničar",
        "Medicinska sestra/medicinski tehničar specijalist",
        "Medicinski biokemičar",
        "Medicinski biokemičar specijalist",
        "Mehaničar poljoprivredne mehanizacije",
        "Mesar",
        "Mlinar",
        "Mljekar",
        "Mornar",
        "Muzejski pedagog",
        "Muzejski pedagog savjetnik",
        "Muzejski savjetnik",
        "Muzejski tehničar",
        "Nadzornik",
        "Nadzornik tehničke ispravnosti vozila",
        "Nadzornik za okoliš",
        "Nastavnik predmetne nastave u srednjoj školi",
        "Natkonobar",
        "Nautički inspektor",
        "Obućar",
        "Ocjenjivač lovačkih trofeja",
        "Odgajatelj u učeničkom domu",
        "Odgojitelj djece predškolske dobi",
        "Odgovorna osoba za ocjenjivanje sukladnosti građevinskih proizvoda",
        "Odvjetnik",
        "Ortopedski obućar",
        "Osoba koja provodi energetske preglede građevina i/ili energetsko certificiranje zgrada",
        "Osoba stručno osposobljena za gospodarski ribolov",
        "Osoba stručno osposobljena za obavljanje akvakulture",
        "Osoba stručno osposobljena za uzgoj riba i drugih morskih organizama",
        "Osoblje za održavanje  zrakoplova (mehaničari, tehničari i inženjeri)",
        "Ovlaštena osoba za izradu elaborata zaštite od požara",
        "Ovlašteni arhitekt",
        "Ovlašteni arhitekt – urbanist",
        "Ovlašteni carinski službenik",
        "Ovlašteni carinski zastupnik",
        "Ovlašteni inženjer drvne tehnologije",
        "Ovlašteni inženjer elektrotehnike",
        "Ovlašteni inženjer geodezije",
        "Ovlašteni inženjer građevinarstva",
        "Ovlašteni inženjer strojarstva",
        "Ovlašteni inženjer tehnologije prometa i transporta",
        "Ovlašteni inženjer šumarstva",
        "Ovlašteni ispitivač",
        "Ovlašteni revident iz zaštite od požara",
        "Ovlašteni revizor",
        "Ovlašteni unutarnji revizor za javni sektor",
        "Očni optičar",
        "Pediker",
        "Pekar",
        "Pećar",
        "Pirotehničar",
        "Pirotehnički nadglednik",
        "Pirotehnički nadzornik",
        "Pismoslikar",
        "Plinoinstalater",
        "Policajac",
        "Pomoćni djelatnik",
        "Pomoćni knjižničar",
        "Pomoćnik strojovođe",
        "Porezni savjetnik",
        "Precizni mehaničar",
        "Predavač",
        "Pregledač vagona",
        "Preparator",
        "Primalja",
        "Primalja – asistentica",
        "Privatni detektiv",
        "Profesionalni diplomat",
        "Profesionalni pilot aviona",
        "Profesionalni pilot helikoptera",
        "Prometni pilot aviona",
        "Prometni pilot helikoptera",
        "Prometnik vlakova",
        "Prvostupnik fizioterapije",
        "Prvostupnik medicinske radiologije",
        "Prvostupnik medicinsko- laboratorijske dijagnostike",
        "Prvostupnik primaljstva",
        "Prvostupnik radiološke tehnologije",
        "Prvostupnik radne terapije",
        "Prvostupnik sanitarnog inženjerstva",
        "Prvostupnik sestrinstva",
        "Prvostupnik sestrinstva specijalist",
        "Psiholog",
        "Puškar",
        "Radio inspektor sigurnosti plovidbe",
        "Radiološki tehničar",
        "Radnik na stručnim poslovima na izvršenju zadaća turističke zajednice",
        "Radnik zaposlen na rukovodećim poslovima",
        "Ravnatelj ustanove za predškolski odgoj i naobrazbu",
        "Ravnatelj školske ustanove",
        "Referent za poslove registracije vozila",
        "Restaurator",
        "Restaurator majstor",
        "Restaurator savjetnik",
        "Restaurator tehničar",
        "Revident",
        "Rudarski tehničar",
        "Rukovatelj eksplozivnim tvarima",
        "Rukovoditelj tehničkog plovila",
        "Sanitarni tehničar",
        "Sigurnosni savjetnik",
        "Slastičar",
        "Soboslikar – ličilac",
        "Socijalni radnik",
        "Sportski trener",
        "Sportski učitelj / instruktor",
        "Sportski voditelj",
        "Staklar",
        "Stalni sudski procjenitelj",
        "Stalni sudski tumač",
        "Stalni sudski vještak",
        "Stolar",
        "Strojar unutarnje plovidbe",
        "Strojobravar",
        "Strojovođa",
        "Strukovni učitelj u srednjoj školi",
        "Stručni radnik u djelatnosti socijalne skrbi",
        "Stručni radnik u ustanovi socijalne skrbi",
        "Stručni suradnik ovlaštenog inženjera geodezije",
        "Stručni suradnik u predškolskoj ustanovi",
        "Stručni suradnik u školskoj ustanovi",
        "Stručni voditelj autoškole",
        "Stručnjak zaštite na radu",
        "Suradnik ovlaštenog inženjera geodezije",
        "Suradnik u nastavi",
        "Tapetar",
        "Tesar",
        "Tokar",
        "Turistički pratitelj",
        "Turistički vodič",
        "Upravitelj prijevoza (osoba odgovorna za prijevoz)",
        "Urar",
        "Učitelj predmetne nastave u osnovnoj školi",
        "Učitelj razredne nastave u osnovnoj školi",
        "Učitelj stručnih predmeta",
        "Veterinar",
        "Veterinarski tehničar",
        "Viši arhivist",
        "Viši arhivski tehničar",
        "Viši dokumentarist",
        "Viši fotograf",
        "Viši informatičar",
        "Viši inspektor",
        "Viši inspektor cestovnog prometa i cesta",
        "Viši inspektor zaštite okoliša",
        "Viši inspektor zaštite prirode",
        "Viši knjižničar",
        "Viši konzervator",
        "Viši konzervator tehničar",
        "Viši konzervator tehničar II stupnja",
        "Viši konzervator –  restaurator",
        "Viši kustos",
        "Viši muzejski pedagog",
        "Viši muzejski tehničar",
        "Viši preparator",
        "Viši restaurator",
        "Viši restaurator tehničar",
        "Vlakovođa",
        "Voditelj ispostave",
        "Voditelj poslovnice turističke agencije",
        "Voditelj projekta",
        "Voditelj radilišta",
        "Voditelj radova",
        "Voditelj skele u nacionalnoj plovidbi",
        "Vodoinstalater",
        "Vodoinstalater, instalater grijanja i klimatizacije",
        "Vojnik",
        "Vozač teretnog motornog vozila i autobusa",
        "Vođa palube",
        "Zapovjednik plovila (vrsta A, vrsta B, vrsta C)",
        "Zaštitar",
        "Zaštitar-tehničar",
        "Zdravstveno laboratorijski tehničar",
        "Zidar",
        "Zlatar",
        "Časnik",
        "Član kabinske posade zrakoplova",
        "Čuvar",
        "Čuvar prirode",
    ]
