from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``uk_UA`` locale."""

    word_list = (
        "увійти",
        "монета",
        "підкинути",
        "бажання",
        "іспит",
        "податковий",
        "витягувати",
        "приятель",
        "здригатися",
        "купа",
        "порт",
        "точно",
        "заплакати",
        "хата",
        "правління",
        "художній",
        "болісно",
        "зображати",
        "ліхтарик",
        "міф",
        "сумний",
        "небезпека",
        "міра",
        "пастух",
        "факультет",
        "мигнути",
        "польовий",
        "інший",
        "виражений",
        "забирати",
        "рот",
        "народ",
        "відповідність",
        "тута",
        "комунізм",
        "рішення",
        "плід",
        "співрозмовник",
        "обуритися",
        "гідність",
        "господь",
        "болото",
        "інфекція",
        "голубчик",
        "синок",
        "простір",
        "прощення",
        "раніше",
        "хотіти",
        "ленінград",
        "даль",
        "розвинений",
        "близько",
        "більше",
        "спорт",
        "епоха",
        "відповісти",
        "звільнити",
        "порада",
        "прохід",
        "палець",
        "вчора",
        "пристойний",
        "яскраво",
        "білизна",
        "коваль",
        "несподівано",
        "вперед",
        "зате",
        "кільце",
        "перед",
        "мить",
        "плавно",
        "тютюн",
        "число",
        "вивчити",
        "важкий",
        "міркування",
        "салон",
        "ідея",
        "що",
        "світило",
        "порода",
        "сумнівний",
        "бок",
        "очко",
        "незручно",
        "радити",
        "відділ",
        "помовчати",
        "вітати",
        "пробувати",
        "дошлий",
        "сміятися",
        "наполегливо",
        "здригнутися",
        "затягнутися",
        "танцювати",
        "пісенька",
        "вибирати",
        "правильний",
        "намір",
        "здалеку",
        "запустити",
        "насолода",
        "щур",
        "летіти",
        "космос",
        "радість",
        "поїзд",
        "знаходити",
        "гуляти",
        "гіркий",
        "бочок",
        "ніч",
        "щастя",
        "знищення",
        "диявол",
        "коробка",
        "спасти",
        "шкіра",
        "провінція",
        "прелесть",
        "в'язниця",
        "вечір",
        "низький",
        "виблискувати",
        "темніти",
        "сонце",
        "гараж",
        "червʼяк",
        "дружно",
        "настати",
        "блін",
        "степ",
        "самостійно",
        "крутий",
        "картинка",
        "навіщо",
        "робочий",
        "незвичайний",
        "армійський",
        "труп",
        "ягода",
        "близько",
        "монета",
        "природний",
        "юний",
        "район",
        "прихований",
        "зловити",
        "будівництво",
        "палата",
        "мить",
        "триста",
        "штаб",
        "ламати",
        "можливо",
        "полюбити",
        "чоловічок",
        "легко",
        "почуття",
        "струмок",
        "кишеня",
        "гроші",
        "неправда",
        "порівняння",
        "груди",
        "від'їзд",
        "виникнення",
        "степ",
        "збудження",
        "діловий",
        "отже",
        "рідкий",
        "синок",
        "художній",
        "покоління",
        "розстебнути",
        "їжа",
        "вчений",
        "секунда",
        "заспокоїтися",
        "навряд",
        "аж",
        "вскакивать",
        "мимо",
        "падати",
        "потягнутися",
        "загроза",
        "розгубитися",
        "бігати",
        "склянка",
        "о",
        "кпсс",
        "нині",
        "підлога",
        "реклама",
        "при",
        "шкільний",
        "прем'єра",
        "дальній",
        "потрясти",
        "звільнення",
        "покидати",
        "наступати",
        "жити",
        "який",
        "образа",
        "командування",
        "дівка",
        "висловлюватися",
        "головний",
        "другий",
        "князь",
        "соціалістичний",
        "головка",
        "залучати",
        "через",
        "господь",
        "результат",
        "відзначити",
        "адже",
        "падаль",
        "покидати",
        "художній",
        "правий",
        "висіти",
        "лапа",
        "каюта",
        "занадто",
        "нервово",
        "серйозний",
        "зима",
        "заробити",
        "ефект",
        "прірва",
        "плід",
        "щось",
        "що-небудь",
        "казна-хто",
        "висіти",
        "холодно",
        "єдиний",
        "викинути",
        "похмуро",
        "вигнати",
        "вмирати",
        "інший",
        "космос",
        "природа",
        "функція",
        "поставити",
        "оборот",
        "услати",
        "черговий",
        "медицина",
        "функція",
        "зарплата",
        "витримати",
        "розлад",
        "адвокат",
        "затримати",
        "поява",
        "інвалід",
        "інтелектуальний",
        "досліджено",
        "мати",
        "ліворуч",
        "хлопець",
        "мільярд",
        "гіркий",
        "трубка",
        "подробиця",
        "паща",
        "незвичний",
        "угодний",
        "засунути",
        "мета",
        "заборонити",
        "дрімати",
        "розуміти",
        "приходити",
        "нарада",
        "постійний",
        "аналіз",
        "терапія",
        "приятель",
        "процес",
        "академік",
        "метал",
        "розвернутися",
        "жорстокий",
        "інтернет",
        "яблуко",
        "банда",
        "зміна",
        "колектив",
        "похорон",
        "пристрій",
        "квапливий",
        "розводити",
        "промовчати",
        "підземний",
        "полум'я",
        "редактор",
        "теорія",
        "олівець",
        "упор",
        "означати",
        "метелик",
        "чотири",
        "століття",
        "різноманітний",
        "вітрина",
        "ніж",
        "команда",
        "шолом",
        "недолік",
        "протягувати",
        "за",
        "метал",
        "домогтися",
        "доба",
        "чітко",
        "надати",
        "тисяча",
        "заспівати",
        "бригада",
        "дрібниця",
        "виражений",
        "перетнути",
        "сходити",
        "взагалі",
        "рис",
        "банк",
        "бак",
        "передо",
        "призначити",
        "важливий",
        "правління",
        "палиця",
        "трясти",
        "упустити",
        "вітрина",
        "основа",
        "так",
        "мʼята",
        "пірʼя",
        "перебивати",
        "дихання",
        "застосовуватися",
        "червень",
        "бетонний",
        "уникати",
        "благати",
        "м'який",
        "заява",
        "конференція",
        "встати",
        "свіжий",
        "супроводжуватися",
        "ланцюжок",
        "вираз",
        "кут",
        "черевик",
        "лягати",
        "інструкція",
        "присісти",
        "решітка",
        "єврейський",
        "поріг",
        "зелений",
        "кордон",
        "ставити",
        "сміливий",
        "суглоб",
        "роса",
        "демократія",
        "вивести",
        "конструкція",
        "задерти",
        "багряний",
        "військовий",
        "направо",
        "житель",
        "товар",
        "солома",
        "ґазда",
        "ґаздиня",
        "ґудзик",
        "неправда",
        "матерія",
        "командувач",
        "кидати",
        "закласти",
        "ліловий",
        "слати",
        "гіркий",
        "простір",
        "провал",
        "сміття",
        "наштовхнутися",
        "торгівля",
        "монета",
        "місце",
        "спалити",
        "брову",
        "лівий",
        "хліб",
        "коричневий",
        "подвірʼя",
        "потім",
        "червонй",
        "пристрасть",
        "виднітися",
        "розкішний",
        "спосіб",
        "багаття",
        "заклад",
        "пропадати",
        "занадто",
        "п'ятеро",
        "програміст",
        "кора",
        "хлопчисько",
        "тьмяний",
        "несподіваний",
        "танцювати",
        "безглуздий",
        "здригнутися",
        "скинути",
        "прошепотіти",
        "безпорадний",
        "рота",
        "пісня",
        "тривога",
        "деякий",
        "термін",
        "пити",
        "колишній",
        "натиснути",
        "видимо",
        "валюта",
        "набір",
        "боєць",
        "райком",
        "новий",
        "ковзати",
        "керівник",
        "вовк",
        "зрідка",
        "зрозумілий",
        "пропаганда",
        "зупинити",
        "виконувати",
        "хід",
        "пані",
        "друкувати",
        "командир",
        "знімати",
        "страта",
        "ручка",
        "камінчик",
        "нога",
        "нестерпний",
        "спорт",
        "тривога",
        "уточнити",
        "актриса",
        "повністю",
        "покинути",
        "блискучий",
        "мотоцикл",
        "дорогий",
        "вказаний",
        "ремінь",
        "присвятити",
        "один",
        "а",
        "їсти",
        "діставати",
        "господиня",
        "шкарпетка",
        "написати",
        "єврейський",
        "заклик",
        "збільшуватися",
        "байдужий",
        "грати",
        "співати",
        "й",
        "фахівець",
        "купа-невеличка",
    )

    parts_of_speech: Dict[str, tuple] = {}
